\NeedsTeXFormat{LaTeX2e}[2020/02/02]
\ProvidesClass{vtg}
[2020/02/02 v1 VOJNOTEHNIČKI GLASNIK /MILITARY TECHNICAL COURIER]

\newif\if@naucni
\DeclareOption{naucni}{\@naucnitrue}
\newif\if@strucni
\DeclareOption{strucni}{\@strucnitrue}
\newif\if@pregledni
\DeclareOption{pregledni}{\@preglednitrue}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[a4paper,twoside]{article}
\hbadness=500
\vbadness=500
\topmargin=0\p@
\emergencystretch=5pt
\sloppy
%%%
\RequirePackage[no-math]{fontspec}
\RequirePackage{polyglossia}
\setotherlanguage[Script=Cyrillic]{serbian}
\setotherlanguage{russian}
\setotherlanguage{spanish}
%
\setmainfont{Arial}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ukida prelamanje reci     %
% Bojan 13-12-2020          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%\tolerance=1
%\emergencystretch=\maxdimen
%\hyphenpenalty=10000
%\hbadness=10000

%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%
\RequirePackage{amsmath,amsfonts,amssymb,bbm} % = dodato amssymb 13-12-2020 Bojan =
\RequirePackage{slashed,feynmp-auto} % = dodato amssymb 13-11-2021 Bojan =
\RequirePackage{float} % = dodato 19-12-2020 Bojan =
\RequirePackage{pgfplots}
\pgfplotsset{height=7cm,compat=1.9}
\allowdisplaybreaks
\RequirePackage{tabularx}
\newcolumntype{L}[1]{>{\raggedright\arraybackslash}p{#1}}
\newcolumntype{C}[1]{>{\centering\arraybackslash}p{#1}}
\newcolumntype{R}[1]{>{\raggedleft\arraybackslash}p{#1}}

\RequirePackage{mathrsfs}
\RequirePackage{changepage}
\RequirePackage{array}
\RequirePackage{calc}
\def\duztxt{\textwidth-2\tabcolsep-1.25\arrayrulewidth}
\RequirePackage{environ}
\RequirePackage{lastpage}
\RequirePackage{mdframed}
\RequirePackage{multirow}
\RequirePackage{ragged2e}
\RequirePackage{footmisc}
\setlength\footnotemargin{0.3em}
\RequirePackage{enumitem}
\setlist[enumerate]{noitemsep,labelindent=\parindent, leftmargin=*,
	label=\arabic*.,%align=left,
	itemsep=3pt,topsep=0pt}
\setlist[itemize]{noitemsep,labelindent=\parindent,
	leftmargin=*,itemsep=3pt,topsep=0pt,align=left}
%\RequirePackage[table]{xcolor}
\RequirePackage{booktabs}
\RequirePackage{tabularx}
\RequirePackage{float}
\RequirePackage{graphicx}
\graphicspath{{./figures/}}
\RequirePackage{academicons}
\definecolor{orcidlogocol}{cmyk}{0.4,0,1,0}
\newcommand\orcid[1]{ORCID iD: \href{#1}{\textcolor{orcidlogocol}{\aiOrcid}#1}} % Dodato ORCID iD Bojan 13-12-2020
\RequirePackage{authblk}
\RequirePackage{varwidth}
\RequirePackage[breaklinks=true,colorlinks = true,allcolors = blue]{hyperref}
\RequirePackage[hyphens]{xurl}

\RequirePackage{url}
\renewcommand\UrlFont{\rmfamily}
\expandafter\def\expandafter\UrlBreaks\expandafter{\UrlBreaks%  save the current one
	\do\a\do\b\do\c\do\d\do\e\do\f\do\g\do\h\do\i\do\j%
	\do\k\do\l\do\m\do\n\do\o\do\p\do\q\do\r\do\s\do\t%
	\do\u\do\v\do\w\do\x\do\y\do\z\do\A\do\B\do\C\do\D%
	\do\E\do\F\do\G\do\H\do\I\do\J\do\K\do\L\do\M\do\N%
	\do\O\do\P\do\Q\do\R\do\S\do\T\do\U\do\V\do\W\do\X%
	\do\Y\do\Z\do\/\do-}

%\RequirePackage{harvard}
\RequirePackage{natbib}

\renewcommand\@biblabel[1]{#1} % No brackets for the references
\renewenvironment{thebibliography}[1]
{\section*{\em\refname}%
	\@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
	\list{\itemsep\@biblabel{\@arabic\c@enumiv}}%
	{\fontsize{10pt}{12}\selectfont%
		\setlength{\itemsep}{-1pt plus 1pt minus 1pt}\settowidth\labelwidth{\@biblabel{#1}}%
		\leftmargin=0pt%\labelwidth%
		\advance\leftmargin0pt% change 20 pt according to your needs
		%\advance\leftmargin\labelsep%
		\setlength\itemindent{\parindent}% change using the inverse of the length used before
		\@openbib@code
		\usecounter{enumiv}%
		\let\p@enumiv\@empty
		\renewcommand\theenumiv{\@arabic\c@enumiv}}%
	\sloppy
	\clubpenalty4000
	\@clubpenalty \clubpenalty
	\widowpenalty4000%
	\sfcode`\.\@m}
{\def\@noitemerr
	{\@latex@warning{Empty `thebibliography' environment}}%
	\endlist}
\renewcommand\newblock{\hskip .11em\@plus.33em\@minus.07em}
\RequirePackage{tikz}
\usetikzlibrary{shapes.geometric}
\RequirePackage{tikzpagenodes}
\usetikzlibrary{decorations.pathmorphing,calc,positioning}

%%%%%%%%%%
%fontsize
%%%%%%%%%%
\renewcommand\normalsize{%
	\@setfontsize\normalsize{11}{14}%
	\abovedisplayskip 11\p@ \@plus2\p@ \@minus5\p@
	\abovedisplayshortskip \z@ \@plus3\p@
	\belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
	\belowdisplayskip \abovedisplayskip
	\let\@listi\@listI}
\normalsize
\let\@bls\baselineskip

\def\scriptsize{\@setfontsize\scriptsize{6.5pt}{9.5pt}}
\def\tiny{\@setfontsize\tiny{5pt}{7pt}}
\def\large{\@setfontsize\large{11.5pt}{12pt}}
\def\Large{\@setfontsize\Large{14pt}{16}}
\def\LARGE{\@setfontsize\LARGE{15pt}{17pt}}
\def\huge{\@setfontsize\huge{22pt}{22pt}}
\def\Huge{\@setfontsize\Huge{30pt}{30pt}}

%fonts
\def\titlefont{\fontsize{15}{18}\selectfont}
\def\authorfont{\fontsize{10,5}{12}\selectfont\normalfont}
\def\papertypefont{\fontsize{10}{12}}
\def\sectionfont{\fontsize{14}{18}\selectfont}
\def\subsectionfont{\fontsize{13}{15}\selectfont}
\def\subsubsectionfont{\fontsize{12}{14}\selectfont}
%
%\RequirePackage{stackengine}
\renewcommand{\DJ}{\stackinset{l}{0.1ex}{c}{}{\rule{0.33em}{0.3pt}}{D}}

%%%%
\def\@corraddress{}
\def\@presentaddress{}
\def\@papereditor{}
\def\@paperreceived{}
\def\@paperdoi{}
\def\@paperudc{}
\def\@issue{}
\def\@papernumber{}
\def\@runningauthor{}
\def\@papertype{}
\def\@field{}
\def\@articletype{}
\def\@sidetitle{}
\def\@volumeyear{}

\newcommand{\corraddress}[1]{\def\@corraddress{#1}}
\newcommand{\presentadd}[2][]{
	\ifx\empty\@presentaddress\else\appto{\@presentaddress}{\\}{}{}\fi
	\appto{\@presentaddress}{%
		\ifx\empty#1\else\textsuperscript{#1}\fi
		#2%
	}{}{}
} \newcommand{\papereditor}[1]{\def\@papereditor{#1}}
\newcommand{\paperreceived}[1]{\def\@paperreceived{#1}}
\newcommand{\paperdoi}[1]{\def\@paperdoi{#1}}
\newcommand{\paperudc}[1]{\def\@paperudc{#1}}
\newcommand{\runningauthor}[1]{\def\@runningauthor{#1}}
\newcommand{\issue}[1]{\def\@issue{#1}}
\newcommand{\papernumber}[1]{\def\@papernumber{#1}}
\newcommand{\papertype}[1]{\def\@papertype{#1}}
\newcommand{\articletype}[1]{\def\@articletype{#1}}
\newcommand{\field}[1]{\def\@field{#1}}
\newcommand{\sidetitle}[1]{\def\@sidetitle{#1}}
\newcommand{\copyrightYear}[1]{\def\@copyrightYear{#1}}
\def\volumeyear#1{\gdef\@volumeyear{#1}} \def\received#1{\gdef\@received{#1}}
\def\revised#1{\gdef\@revised{#1}} \def\accepted#1{\gdef\@accepted{#1}} %
\let\affil@mark\@empty \def\keywords#1{%
	\gdef\@keywords{%
		\addvspace\medskipamount
		\noindent\strut{\bfseries Keywords:\/} \ignorespaces#1\unskip}}
\def\@keywords{\ClassWarningNoLine{cj}{No keywords}}
%%%%%
%%%%%
\newcommand{\epm@podaci}{%
	\AB@affillist\par%
	\vskip10pt%
}
%%%%%%%%%%%%%%

\newbox\@abstract%
\def\abstitle{\fontsize{10}{12}\textit{Abstract}}%
\renewenvironment{abstract}{\fontsize{10}{12}\itshape%
	\setlength{\leftskip}{15mm}
	\setlength{\parskip}{2pt}%
	\setlength{\parindent}{\z@}%
	%\abstitle:\par%
	\global\setbox\@abstract\vbox\bgroup%
	
	\noindent\ignorespaces%
}{%
	\egroup%
}%

% Author and affiliation fonts
\setcounter{Maxaffil}{1}
\renewcommand{\Authsep}{, }
\renewcommand{\Authand}{, }
\renewcommand{\Authands}{, }
\renewcommand{\Authfont}{\fontsize{10.5\p@}{22pt}\raggedright}
\renewcommand{\Affilfont}{\fontsize{9\p@}{11pt}\selectfont\raggedright}
\renewcommand\AB@authnote[1]{\textsuperscript{#1}}
\renewcommand\AB@affilnote[1]{\textsuperscript{#1}}
\patchcmd{\AB@affilsepx}{\\}{\\[3\p@]}{}{}

\patchcmd{\@author}{\AB@authlist\\[\affilsep]\AB@affillist}{\AB@authlist}{}{}

\newcommand\strucni{
	\vskip -10mm % Bojan 06-02-2021 prosirenje sive pozadine
	\tikz[baseline=(B1.base)]
	{
		\node[shape=rectangle,fill=black!25, minimum height=45mm,minimum width=\textwidth,inner sep=1pt] (B1) % Boja pojacana sa !10 na !25 Bojan 13-12-2020, height=45
		{\centering\renewcommand{\arraystretch}{1.3}\tabcolsep=2.0\tabcolsep
			\begin{tabular}{c}
				\vspace*{4mm}\\ % Bojan 06-02-2021 prosirenje sive pozadine
				%СТРУЧНИ РАДОВИ\\
				%\hline
				%ПРОФЕССИОНАЛЬНЫЕ СТАТЬИ	\\
				%\hline
				PROFESSIONAL PAPERS	
			\end{tabular}
		}
		;}
}

\newcommand\naucni{%
	\vskip -10mm % Bojan 06-02-2021 prosirenje sive pozadine
	\tikz[baseline=(B1.base)]
	{
		\node[shape=rectangle,fill=black!25,minimum height=45mm,minimum width=\textwidth,inner sep=1pt] (B1) % Boja pojacana sa !10 na !25 Bojan 13-12-2020, height=45
		{\centering\renewcommand{\arraystretch}{1.3}\tabcolsep=2.0\tabcolsep
			\begin{tabular}{c}
				\vspace*{4mm}\\ % Bojan 06-02-2021 prosirenje sive pozadine
				%ОРИГИНАЛНИ НАУЧНИ РАДОВИ\\
				%\hline	
				%ОРИГИНАЛЬНЫЕ НАУЧНЫЕ СТАТЬИ	\\
				%\hline
				ORIGINAL SCIENTIFIC PAPERS	
			\end{tabular}
		};
	}
}

\newcommand\pregledni{
	%\vskip -17pt % Pomereno na gore po zahtevu urednika Bojan 13-12-2020
	\vskip -10mm % Bojan 06-02-2021 prosirenje sive pozadine
	\tikz[baseline=(B1.base)]
	{
		\node[shape=rectangle,fill=black!25,minimum height=45mm,minimum width=\textwidth,inner sep=1pt] (B1) % Boja pojacana sa !10 na !25 Bojan 13-12-2020, height=45
		{\centering\renewcommand{\arraystretch}{1.3}\tabcolsep=2.0\tabcolsep
			\begin{tabular}{c}
				\vspace*{4mm}\\ % Bojan 06-02-2021 prosirenje sive pozadine
				%ПРЕГЛЕДНИ РАДОВИ\\
				%\hline
				%ОБЗОРНЫЕ СТАТЬИ\\
				%\hline
				REVIEW PAPERS	
			\end{tabular}
		}
		;}
}

%%%%%%%%%%%%%%
\def\maketitle{
	{%
		\thispagestyle{title}
		\parindent=0pt
		\vskip -0.75\baselineskip
		\if@strucni
		{\vspace*{-26mm}
			\strucni\par}
		\vskip 0.75\baselineskip
		\else
		\if@naucni
		{\vspace*{-26mm}
			\naucni\par}
		\vskip 0.75\baselineskip
		\else
		\if@pregledni
		{\vspace*{-26mm}
			\pregledni\par}
		\vskip 0.75\baselineskip
		\else
		\fi\fi\fi
		{\hfill\parbox[b]{0.8\textwidth}{\raggedright
				{\titlefont{\@title}\par}%
				
				\addvspace{6pt}
				{\large\authorfont\@author\relax\par}%   % Obrisano \par iza \relax Bojan 13-12-2020 
				%\addvspace\bigskipamount
				\vskip 0.3\baselineskip
				\epm@podaci
				\vskip 0.1\baselineskip
				\rightline{DOI: {\url{\@paperudc}}}% obrisano \url kod \paperdoi
				%DOI: {\@paperdoi;\url{\@paperudc}} % obrisano \url kod \paperdoi
		}}
		\vskip 0.3\baselineskip%
		{\small\setlength{\leftskip}{15mm}
			FIELD: \@field
			\vskip 0.1\baselineskip
			ARTICLE TYPE: \@articletype
			\par
		}
		\vskip 0.5\baselineskip%
		{\small\setlength{\leftskip}{15mm}\abstitle:\par}
		\vskip 8pt % \vskip 0.5em promenjen u 8pt da bi se udaljio naslov abstrakta od sadržaja abstrakta Bojan 13-12-2020
		{\unvbox\@abstract\par}%
		%\vspace{-1pt}%
		\vspace{1pt}%
	}%
	\let\and\relax
	\let\author\relax
	\let\@affils\relax
	\let\keywords\relax
	\let\@keywords\relax
	\let\maketitle\relax
	\let\thanks\@gobble
	%	\vfill\clearpage % deo koji sprecava da se abstrakt razvuce Bojan 25-01-2021
}
\def\endpage#1{\gdef\@endpage{#1}}
\endpage{}%
%%%
%%%%%%%%%%%%%%%%%%%
%% Headers&footers
%%%%%%%%%%%%%%%%%%%
\RequirePackage{fancyhdr}
\fancyhf{}
\renewcommand{\headrule}{}
\fancyfoot[CO]{\tikz[remember picture,overlay,baseline=(E.base)]{
		\node[draw=black,
		line width=0.5pt,
		font=\fontsize{14pt}{14pt}\selectfont,
		shape=ellipse,minimum height=9mm,minimum width=18mm,inner sep=0pt] (E){\thepage};
		\draw[line width=0.5pt](E.east)--++(59mm,0)--+(0,245mm);
		\node[font=\fontsize{9pt}{9}\selectfont,rotate=90,anchor=north east,inner sep=0pt]at([yshift=0mm,xshift=7mm]current page text area.north east)
		{\@runningauthor, \@sidetitle, pp.\pageref{FirstPage}--\pageref{LastPage}}
	}
}
%%%%
\fancyfoot[CE]{\tikz[remember picture,overlay,baseline=(E.base)]{
		\node[draw=black,
		line width=0.5pt,
		font=\fontsize{14pt}{14pt}\selectfont,
		shape=ellipse,minimum height=9mm,minimum width=18mm,inner sep=0pt] (E){\thepage};
		\draw[line width=0.5pt](E.west)--++(-59mm,0)--+(0,245mm);
		\node[font=\fontsize{9pt}{9}\selectfont,rotate=90,anchor=north east,inner sep=0pt]at([yshift=0mm,xshift=-11mm]current page text area.north west)
		(TT){VOJNOTEHNIČKI GLASNIK / MILITARY TECHNICAL COURIER, \@volumeyear, Vol. \@issue, Issue
			\@papernumber};
		%\fill [black] (TT.west) circle (0.2);
		\node[below left=0mm and 5.5mm of TT,rotate=90]{\includegraphics[scale=0.25]{logo-vtg}}
}}
%~

%% First page header + footer
\fancypagestyle{title}{
	\fancyhf{}
	\checkoddpage
	\ifoddpage
	\fancyfoot[CO]{
		\tikz[remember picture,overlay,baseline=(E.base)]{
			\node[draw=black,
			line width=0.5pt,
			font=\fontsize{14pt}{14pt}\selectfont,
			shape=ellipse,minimum height=9mm,minimum width=18mm,inner sep=0pt] (E){\thepage};
			\draw[line width=0.5pt](E.east)--++(59mm,0)--+(0,245mm);
			\node[font=\fontsize{9pt}{9}\selectfont,rotate=90,anchor=north east,inner sep=0pt]at([yshift=0mm,xshift=7mm]current page text area.north east)
			{\@runningauthor, \@sidetitle, pp.\pageref{FirstPage}--\pageref{LastPage}}}
	}
	\else
	\fancyfoot[CE]{\tikz[remember picture,overlay,baseline=(E.base)]{
			\node[draw=black,
			line width=0.5pt,
			font=\fontsize{14pt}{14pt}\selectfont,
			shape=ellipse,minimum height=9mm,minimum width=18mm,inner sep=0pt] (E){\thepage};
			\draw[line width=0.5pt](E.west)--++(-59mm,0)--+(0,245mm);
			\node[font=\fontsize{9pt}{9}\selectfont,rotate=90,anchor=north east,inner sep=0pt]at([yshift=0mm,xshift=-11mm]current page text area.north west)
			(TT){VOJNOTEHNIČKI GLASNIK / MILITARY TECHNICAL COURIER, \@volumeyear, Vol. \@issue, Issue
				\@papernumber};
			%\fill [black] (TT.west) circle (0.2);
			\node[below left=0mm and 5.5mm of TT,rotate=90]{\includegraphics[scale=0.25]{logo-vtg}}
	}}
	\fi
}

%\setlength\parskip{2pt plus 2pt minus 2pt}
%\setlength\parindent{8mm}
%\setlength\topsep{8pt plus 2pt minus 4pt}
%\setlength\partopsep{0pt plus 2pt}
%\setlength\itemsep{0pt plus 1pt}
%\def\@seccntformat#1{\csname the#1\endcsname.\quad}

%%%%%%%%%%%%%%%%%%%%%%%
%naslovi
%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage[explicit]{titlesec}

\titleformat{\section}
{\sectionfont}
{\thesection.}{0.5em}{#1}%\MakeUppercase{
	
	\titleformat{name=\section,numberless}
	{\sectionfont}
	{}{0pt}{#1}
	
	\titlespacing{\section}{\parindent}{1.25\baselineskip plus 4pt minus 4pt}{0.5\baselineskip plus 2pt minus 2pt}
	\titlespacing{name=\section,numberless}{\parindent}{1\baselineskip plus 4pt minus 4pt}{0.5\baselineskip plus 4pt minus 2pt}
	
	\titleformat{\subsection}
	{\subsectionfont\raggedright}
	{\thesubsection.}{0.5em}{#1}
	
	\titleformat{name=\subsection,numberless}
	{\subsectionfont}
	{}{0pt}{#1}
	
	\titlespacing{\subsection}{\parindent}{1.2\baselineskip plus 4pt minus 4pt}{0.35\baselineskip plus 4pt minus 4pt}
	\titlespacing{name=\subsection,numberless}{\parindent}{1.2\baselineskip plus 4pt minus 2pt}{0.35\baselineskip plus 4pt minus 2pt}
	
	\titleformat{\subsubsection}
	{\subsectionfont\raggedright}
	{\thesubsubsection.}{0.5em}{\subsubsectionfont #1}
	
	\titleformat{name=\subsubsection,numberless}
	{\subsubsectionfont}
	{}{0pt}{#1}
	
	\titlespacing{\subsubsection}{\parindent}{1.2\baselineskip}{0.35\baselineskip}
	\titlespacing{name=\subsubsection,numberless}{\parindent}{1.2\baselineskip}{0.35\baselineskip}
	
	
	\setcounter{secnumdepth}{0}
	\setcounter{tocdepth}{0}
	\def\fps@eqnfloat{!tp}
	\def\fps@table{!htb}
	\def\ftype@eqnfloat{4}
	\newenvironment{eqnfloat}
	{\@float{eqnfloat}}
	{\end@float}
	\newenvironment{eqnfloat*}
	{\@dblfloat{eqnfloat}}
	{\end@dblfloat}
	\let\originaltable\table
	\let\endoriginaltable\endtable
	\renewenvironment{table}[1][htb]{%
		\originaltable[#1]\small
		\centering}%
	{\endoriginaltable}
	%\renewenvironment{table*}
	%               {\@dblfloat{table}\small\ignorespaces}
	%               {\end@dblfloat}
	%%%%
	%caption of figure and table
	%%%%
	\RequirePackage{subcaption}
	\DeclareCaptionFont{ninept}{\fontsize{10pt}{12}\selectfont}
	\captionsetup[figure]{skip=6pt,labelfont={it,ninept},labelsep=endash,justification=centering,
		font={it,ninept}}
	\captionsetup[table]{skip=4pt,labelfont={it,ninept},labelsep=endash,justification=centering,
		font={it,ninept}}
	\def\fnum@figure{\figurename~\thefigure}
	\def\fnum@table{\tablename~\thetable}
	
	\RequirePackage{amsthm}
	\let\c@lenddoca\relax
	\newtheoremstyle{theor}
	{9pt}% above space (default)
	{12pt}% below space
	{\itshape}% body
	{0em}% indent
	{\scshape}% head
	{.}% punct
	{ }% space
	{}% custom
	\theoremstyle{theor}
	
	\newtheorem{definition}{Definition}
	\def\thedefinition{\arabic{definition}}
	\newtheorem{lemma}{Lemma}[section]
	\def\thelemma{\arabic{lemma}}
	\newtheorem{proposition}{Proposition}
	\def\theproposition{\arabic{proposition}} % = obrisano \. ispred \arabic Bojan 13-12-2020 = %
	\newtheorem{problem}{Problem}[section] % = dodato Bojan 13-12-2020 = %
	\newtheorem{corollary}{Corollary}
	\def\thecorollary{\arabic{corollary}}
	
	\newtheoremstyle{remark}
	{9pt}% above space (default)
	{9pt}% below space
	{\normalfont}% body
	{0em}% indent
	{\scshape}% head
	{.}% punct
	{ }% space
	{}% custom
	\theoremstyle{remark}
	
	\newtheorem{remark}{Remark}
	\newtheorem{example}{Example}
	
	{\theoremstyle{theor}
		\newtheorem{theorem}{Theorem}
		\def\thetheorem{\arabic{theorem}}
	}
	
%%%%%%%%%%%%%%%
%page dimensions
%%%%%%%%%%%%%%%
\setlength\marginparsep{0mm}%1mm}
\RequirePackage[paperwidth=210mm,paperheight=297mm,
bottom=56mm,% 49.5mm,
top=56mm, %49.5mm,%showcrop,
inner=42mm, %41.5mm,
outer=42mm, %41.5mm,
footskip=12mm,%showframe,
headheight=5mm,
headsep=5mm,
marginparwidth=0mm
]{geometry}%
\setlength\columnsep{6mm}

%Appendix commands
\def\appendix{\@@par
	\@addtoreset{table}{section}
	\@addtoreset{figure}{section}
	\@addtoreset{equation}{section}
	\setcounter{section}{0}
	\setcounter{subsection}{0}
	\setcounter{subsubsection}{0}
	\setcounter{equation}{0}
	\setcounter{figure}{0}
	\setcounter{table}{0}
	\def\thesection{Appendix~\Alph{section}}
	\def\thelemma{\Alph{section}.\arabic{lemma}}
	\def\thedefinition{\Alph{section}.\arabic{definition}}
	\def\thetheorem{\Alph{section}.\arabic{theorem}}
	\def\theproposition{\Alph{section}.\arabic{proposition}}
	\def\thecorollary{\Alph{section}.\arabic{corollary}}
	\def\theaxiom{\Alph{section}.\arabic{axiom}}
	\def\theequation{%
		\Alph{section}.\arabic{equation}}
	\def\thetable{%
		\Alph{section}.\arabic{table}}
	\def\thefigure{%
		\Alph{section}.\arabic{figure}}
}

% Disallow widows and orphans
\clubpenalty 10000
\widowpenalty 10000

% Disable page breaks before equations, allow pagebreaks after
% equations and discourage widow lines before equations.
\displaywidowpenalty 100
\predisplaypenalty   10000
\postdisplaypenalty  2500

% Allow breaking the page in the middle of a paragraph
\interlinepenalty 0

% Disallow breaking the page after a hyphenated line
% Hyphenation; don't split words into less than three characters
\lefthyphenmin=2
\righthyphenmin=2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% prva-poslednja strana
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% izbaceno  04-12-2021 Bojan
%\def\enddocument{%
%   \@enddocumenthook
%   \@checkend{document}%
%        \immediate\write\@mainaux{\string\endpage{\thepage}}
%%
%   \gdef\endpage{\thepage}
%   \deadcycles\z@\@@end}

%bold math u naslovu
\g@addto@macro\bfseries{\boldmath}
\renewcommand{\@seccntformat}[1]{\csname the#1\endcsname.\quad}

%\newcommand\atenddocument{\vspace*{12pt} \hrule\@height.5pt \vspace{5pt} {\noindent
\newcommand\atenddocument{\vspace*{12pt} {\noindent
		%\small Paper received on / Дата получения работы / Датум пријема чланка:
		%\@received. Manuscript corrections submitted on / Дата получения исправленной
		%версии работы / Датум достављања исправки рукописа: \@revised. \\
		%Paper accepted for publishing on / Дата окончательного согласования работы / Датум коначног
		%прихватања чланка за објављивање: \@accepted. }\par\medskip
	
		\small Paper received on: \@received.\\ 
		Manuscript corrections submitted on: \@revised. \\
		Paper accepted for publishing on: \@accepted. }\par\medskip
			
		{\footnotesize\parindent=0pt\raggedright 
			\textcopyright~ \@copyrightYear~ The Authors. Published by
			Vojnotehnički glasnik / Military Technical Courier
			(\url{http://vtg.mod.gov.rs}, \url{http://втг.мо.упр.срб}). This article is an
			open access article distributed under the terms and conditions of the Creative
			Commons Attribution license
			(\url{http://creativecommons.org/licenses/by/3.0/rs/}). \par\medskip
				
			%\textcopyright~ \@copyrightYear~ Авторы. Опубликовано в "Военно-технический вестник / Vojnotehnički
			%glasnik / Military Technical Courier" (\url{http://vtg.mod.gov.rs},
			%\url{http://втг.мо.упр.срб}). Данная статья в открытом доступе и
			%распространяется в соответствии с лицензией "Creative Commons"
			%(\url{http://creativecommons.org/licenses/by/3.0/rs/}). \par\medskip
				
			%\textcopyright~ \@copyrightYear~ Аутори. Објавио Војнотехнички гласник / Vojnotehnički glasnik / Military
			%Technical Courier (\url{http://vtg.mod.gov.rs}, \url{http://втг.мо.упр.срб}).
			%Ово је чланак отвореног приступа и дистрибуира се у складу са Creative Commons
			%лиценцом (\url{http://creativecommons.org/licenses/by/3.0/rs/}).\par
		} 
		\includegraphics[scale=1.0]{logo-cc} 
}
		
\newcommand\acknowledgment[1]{%
	\begingroup
	\setlength\footnotemargin{0em}
	\renewcommand\thefootnote{}\footnote{ACKNOWLEDGMENT: #1}%
	\addtocounter{footnote}{-1}%
	\endgroup
}
		
		
\newcommand\nasrezime[1]{{%
		\vskip 0.2\baselineskip%
		\fontsize{10pt}{12}\selectfont%
		\parindent=0pt%
		\RaggedRight%\leftskip=20mm
			#1%
		\vskip 0.5\baselineskip%
}}
		
\newcommand\authorrezime[1]{{%
		\fontsize{9pt}{11}\selectfont%
		\parindent=0pt%
		\RaggedRight#1%\leftskip=20mm %
		\par
		\vskip -2pt
		\vskip 0.5\baselineskip%
}}
		
\newcommand\rezime[1]{%
	%	\RaggedRight
	\parindent=0pt
	\fontsize{10pt}{12}\selectfont
	%\vskip 0.5\baselineskip%
	%\hrule
	%\vskip 0.5\baselineskip
	%\hfill
	\begin{mdframed}[leftmargin =20mm,
		usetwoside=false,
		topline=false,bottomline=false,
		leftline=false,rightline=false]
			#1
	\end{mdframed}
}
		
\newcommand\rezimetext[2][serbian]{%
	%\RaggedRight
	\parskip=3pt%
	\fontsize{10pt}{12}\selectfont
	\parindent=0pt
	\begin{hyphenrules}{#1}
		\em #2
	\end{hyphenrules}
}
		
\newcommand\summary[3]{%
	\vskip 1.5\baselineskip
	\hrule
	\vskip 0.5\baselineskip
	\nasrezime{#1}
	\authorrezime{#2}
	\par
	\rezimetext[russian]{#3}
}
		
%page style
\pagestyle{fancy}

\endinput
